@@ -45,7 +45,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'	=> 'اللغة الافتراضية',
 	'DEFAULT_STYLE'	=> 'الاستايل الافتراضي',
 	'DISABLE_BOARD'	=> 'تعطيل المنتدى',
-	'DISABLE_BOARD_EXPLAIN'	=> 'يغلق المنتدى ولن يكون متاحاً للمستخدمين ، يمكنك أيضاً وضع رسالة أقصى عدد حروفها 255 لتبين سبب تعطيل المنتدى',
+	'DISABLE_BOARD_EXPLAIN'	=> 'يغلق المنتدى ولن يكون متاحاً للمستخدمين الذين ليسوا مدراء أو مشرفين، يمكنك أيضاً وضع رسالة أقصى عدد حروفها 255 لتبين سبب تعطيل المنتدى',
 	'OVERRIDE_STYLE'	=> 'تجاوز استايل المستخدم',
 	'OVERRIDE_STYLE_EXPLAIN'	=> 'غير الاستايل المستخدم الى الاستايل الافتراضي',
 	'SITE_DESC'	=> 'وصف الموقع',
@@ -105,7 +105,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'	=> 'مسار معرض الصور الشخصية',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'مسار تحت المنتدى إلى معرض الصور الشخصية مثال <samp>images/avatars/gallery</samp>',
 	'AVATAR_STORAGE_PATH'	=> 'مسار تخزين الصور الشخصية',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'مسار تحت مجلد المنتدى مثال <samp>images/avatars/upload</samp>',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'مسار تحت مجلد المنتدى مثال <samp>images/avatars/upload</samp>.<br />رفع الصور الشخصية <strong>لن يكون ممكناً</strong> إذا لم يكن هذا المسار قابلاً للكتابة.',
 	'MAX_AVATAR_SIZE'	=> 'أقصى الأبعاد للصور الشخصية',
 	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'الارتفاع × العرض بالبكسل',
 	'MAX_FILESIZE'	=> 'أقصى حجم لملف الصورة الشخصية',
