@@ -51,7 +51,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'	=> 'الحظر',
 	'ACP_BAN_EMAILS'	=> 'حظر بريد الكتروني',
 	'ACP_BAN_IPS'	=> 'حظر عناوين IP',
-	'ACP_BAN_USERNAMES'	=> 'حظر أسماء المستخدمين',
+	'ACP_BAN_USERNAMES'	=> 'حظر المستخدمين',
 	'ACP_BBCODES'	=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'	=> 'إعدادات المنتدى',
 	'ACP_BOARD_FEATURES'	=> 'خصائص المنتدى',
