@@ -89,9 +89,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'	=> 'حُمِلّت الصورة جزئيا فقط',
 	'AVATAR_PHP_SIZE_NA'	=> 'حجم الصورة/الصور الشخصية كبير جداً.<br />لا يستطيع النظام تحديد أقصى حجم المعرّف من قبل PHP في ملف php.ini',
 	'AVATAR_PHP_SIZE_OVERRUN'	=> 'حجم الصورة الشخصيه اكبر من الحد المسموح. الحد المسموح هو %1$d %2$s.<br />الرجاء الانتباه إلى أنه لا يمكن تجاوز اعدادت ملف php.ini',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'الصورة الشخصية المحددة لم يتم رفعها لأن وقت الطلب انتهى.',
 	'AVATAR_URL_INVALID'	=> 'أُدخِل العنوان بطريقة خاطئة',
 	'AVATAR_URL_NOT_FOUND'	=> 'لم يُعثَر على الملف المحدد',
-	'AVATAR_WRONG_FILESIZE'	=> 'ينبغي أن يكون حجم الصورة الشخصية بين 0 و %1d %2s',
+	'AVATAR_WRONG_FILESIZE'	=> 'ينبغي أن يكون حجم الصورة الشخصية بين 0 و %1$d %2$s',
 	'AVATAR_WRONG_SIZE'	=> 'ينبغي أن يكون عرض الصورة الشخصية على الأقل %1$d بكسل ، وطولها %2$d بكسل وعلى الأكثر يكون عرضها %3$d بكسل وطولها %4$d بكسل. عرض الصورة المقدّمة هو %5$d بكسل وطولها %6$d بكسل',
 	
 	'BACK_TO_TOP'	=> 'أعلى',
@@ -342,6 +343,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'	=> 'إدارة',
 	'MODERATOR'	=> 'المشرف',
 	'MODERATORS'	=> 'المشرفون',
+	'MODULE_NOT_ACCESS'		=> 'لا يمكون الوصول إلى الوحدة',
+ 	'MODULE_NOT_FIND'		=> 'لا يمكن إيجاد الوحدة %s',
+ 	'MODULE_FILE_INCORRECT_CLASS'	=> 'ملف الوحدة %s لا يحتوي على تصنيف صحيح [%s]',
 	'MONTH'	=> 'شهر',
 	'MOVE'	=> 'نقل',
 	'MSNM'	=> 'MSNM/WLM',
@@ -652,7 +656,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'عدد الأعضاء <strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> 'أخطاء تتبع PHP: %s',
 	
-	'UNABLE_GET_IMAGE_SIZE'	=> 'لم يتمكن من تحديد أبعاد الصورة',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'لم يتمكن من تحديد أبعاد الصورة. يرجى التأكد من صحة الرابط المدخل.',
 	'UNABLE_TO_DELIVER_FILE'	=> 'غير قادر على توصيل الملف',
 	'UNKNOWN_BROWSER'	=> 'متصفح غير معروف',
 	'UNMARK_ALL'	=> 'إلغاء تحديد الكل',
