@@ -267,7 +267,7 @@ $lang = array_merge($lang, array(
 	'MOVE_DELETED_MESSAGES_TO'	=> 'نقل الرسائل من المجلد المحذوف إلى',
 	'MOVE_DOWN'	=> 'تحريك للأسفل',
 	'MOVE_MARKED_TO_FOLDER'	=> 'نقل المحدد إلى %s',
-	'MOVE_PM_ERROR'	=> 'حصل خطأ أثناء نقل الرسائل إلى المجلد الجديد، فقط %1d من أصل %2d رسائل تم نقلها',
+	'MOVE_PM_ERROR'	=> 'حصل خطأ أثناء نقل الرسائل إلى المجلد الجديد، فقط %1$d من أصل %2$d رسائل تم نقلها',
 	'MOVE_TO_FOLDER'	=> 'نقل إلى مجلد',
 	'MOVE_UP'	=> 'تحريك للأعلى',
 	
